#include <iostream>
#include <vector>
#include <iomanip>
#include <map>
#include <queue>
#include <set>
#include <array>
#include <deque>
#include <algorithm>
#include "testlib.h"
#include "gen_lib.h"

using namespace std;
const int INF = 1e9;

struct Test {
    int n, k, maxn = INF;
    vector <int> a;

    void print() {
        println(n, k);
        println(a);
    }
};

Test test;
ArgumentParser parser;

void random_gen() {
    int n = test.n;
    int k = test.k;
    int maxn = test.maxn;

    vector <int> a(n);
    for (int i = 0; i < n; ++i) a[i] = rnd.next(1, maxn);
    test.a = a;
}

void gen_with_last_not_max() {
    int n = test.n;
    int k = test.k;
    int maxn = test.maxn;
    int pos = parser.getInt("pos");
    int some_eq = parser.hasFlag("some_eq");

    vector <int> a(n);
    a[pos] = rnd.next(1, maxn);

    vector <int> ind;
    for (int i = 0; i < pos; ++i) ind.push_back(i);
    shuffle(ind.begin(), ind.end());

    vector <int> is_special(n);
    int last = -1;
    for (int i = 0; i < k - 1; ++i) {
        int j = ind[i];
        is_special[j] = 1;
        last = max(last, j);
        a[j] = rnd.next(a[pos], maxn);
    }


    is_special[pos] = 1;
    int my_imp = pos + 1 + a[pos];

    for (int i = 0; i < n; ++i) {
        if (is_special[i]) continue;
        int max_can;
        if (i < last) {
            max_can = my_imp - (last + 1);
        } else {
            max_can = my_imp - (i + 1);
        }

        if (max_can < 1) max_can = 1;

        if (some_eq && max_can >= a[pos] && rnd.next(1, 5) == 1) {
            a[i] = a[pos];
        } else if (max_can >= a[pos] && rnd.next(1, 5) == 1){
            a[i] = rnd.next(a[pos], max_can);
        } else {
            a[i] = rnd.next(1, max_can);
        }
    }
    test.a = a;
}

void gen_max_ans() {
    int n = test.n;
    int k = test.k;
    int maxn = test.maxn;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) a[i] = maxn;
    test.a = a;
}

void gen_random_dec() {
    int n = test.n;
    int maxn = test.maxn;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) {
        a[i] = rnd.next(1, maxn);
    }
    sort(a.rbegin(), a.rend());
    test.a = a;
}

void gen_random_inc() {
    int n = test.n;
    int maxn = test.maxn;
    vector <int> a(n);
    for (int i = 0; i < n; ++i) {
        a[i] = rnd.next(1, maxn);
    }
    sort(a.begin(), a.end());
    for (int i = 0; i < n; ++i) {
        if (rnd.next(1, 5) == 1 && i && a[i - 1] > 1) {
            a[i] = a[i - 1] - 1;
        }
    }
    test.a = a;
}

void gen_special() {
    int n = test.n;
    int maxn = test.maxn;
    vector <int> a(n);
    a[0] = 2;
    for (int i = 1; i < n; ++i) a[i] = 1;
    test.a = a;
}

signed main(int argc, char** argv) {
    registerGen(argc, argv, 1);
    parser = ArgumentParser(argc, argv);
    test.n = parser.getInt("n");
    test.k = parser.getInt("k");
    if (parser.hasParameter("maxn")) test.maxn = parser.getInt("maxn");
    else test.maxn = INF;

    const auto gen_mode = parser.getString("gmode");
    if (gen_mode == "random") {
        random_gen();
    } else if (gen_mode == "last_not_max") {
        gen_with_last_not_max();
    } else if (gen_mode == "max_ans") {
        gen_max_ans();
    } else if (gen_mode == "random_dec") {
        gen_random_dec();
    } else if (gen_mode == "random_inc") {
        gen_random_inc();
    } else if (gen_mode == "special") {
        gen_special();
    }

    test.print();
}
